@@ -6,15 +6,7 @@ use warnings;
 
 =head1 NAME
 
-WWW::YoutubeViewer::PlaylistItems - ...
-
-=head1 VERSION
-
-Version 0.01
-
-=cut
-
-our $VERSION = '0.01';
+WWW::YoutubeViewer::PlaylistItems - Manage playlist entries.
 
 =head1 SYNOPSIS
 
@@ -73,7 +65,7 @@ Favorite a video. Returns true on success.
 sub favorite_video {
     my ($self, $video_id) = @_;
     $video_id // return;
-    my $playlist_id = $self->get_playlist_id('favorites', mine => 'true');
+    my $playlist_id = $self->get_playlist_id('favorites', mine => 'true') // return;
     $self->add_video_to_playlist($playlist_id, $video_id);
 }
 
@@ -110,7 +102,8 @@ Get favorited videos for a given username or from the current user.
     foreach my $name (qw(favorites uploads likes)) {
         *{__PACKAGE__ . '::' . $name . '_from_username'} = sub {
             my ($self, $username) = @_;
-            my $playlist_id = $self->get_playlist_id($name, $username ? (forUsername => $username) : (mine => 'true'));
+            my $playlist_id = $self->get_playlist_id($name, $username ? (forUsername => $username) : (mine => 'true'))
+              // return;
             $self->videos_from_playlist_id($playlist_id);
         };
 
@@ -121,7 +114,7 @@ Get favorited videos for a given username or from the current user.
                                      $name, ($channel_id and $channel_id ne 'mine')
                                      ? (id => $channel_id)
                                      : (mine => 'true')
-                                    );
+                                    ) // return;
             $self->videos_from_playlist_id($playlist_id);
         };
     }
@@ -144,41 +137,10 @@ You can find documentation for this module with the perldoc command.
 Copyright 2013-2015 Trizen.
 
 This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
-
-L<http://www.perlfoundation.org/artistic_license_2_0>
-
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
-
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
-
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
-
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
 
+See L<http://dev.perl.org/licenses/> for more information.
 
 =cut
 
